--- old/usr/src/lib/libm/common/Q/hypotl.c	2019-06-06 20:38:45.105923267 +0000
+++ new/usr/src/lib/libm/common/Q/hypotl.c	2019-06-06 20:38:45.122160538 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -52,7 +53,7 @@
  *	hypot(x,y) is NAN if x or y is NAN.
  *
  * Accuracy:
- * 	hypot(x,y) returns sqrt(x^2+y^2) with error less than 1 ulps (units
+ *      hypot(x,y) returns sqrt(x^2+y^2) with error less than 1 ulps (units
  *	in the last place)
  */
 
@@ -62,17 +63,17 @@
 extern enum fp_direction_type __swapRD(enum fp_direction_type);
 
 static const long double zero = 0.0L, one = 1.0L;
-
 long double
-hypotl(long double x, long double y) {
+hypotl(long double x, long double y)
+{
 	int n0, n1, n2, n3;
 	long double t1, t2, y1, y2, w;
-	int *px = (int *) &x, *py = (int *) &y;
-	int *pt1 = (int *) &t1, *py1 = (int *) &y1;
+	int *px = (int *)&x, *py = (int *)&y;
+	int *pt1 = (int *)&t1, *py1 = (int *)&y1;
 	enum fp_direction_type rd;
 	int j, k, nx, ny, nz;
 
-	if ((*(int *) &one) != 0) {	/* determine word ordering */
+	if ((*(int *)&one) != 0) {	/* determine word ordering */
 		n0 = 0;
 		n1 = 1;
 		n2 = 2;
@@ -84,11 +85,12 @@
 		n3 = 0;
 	}
 
-	px[n0] &= 0x7fffffff;	/* clear sign bit of x and y */
+	px[n0] &= 0x7fffffff;		/* clear sign bit of x and y */
 	py[n0] &= 0x7fffffff;
 	k = 0x7fff0000;
-	nx = px[n0] & k;	/* exponent of x and y */
+	nx = px[n0] & k;		/* exponent of x and y */
 	ny = py[n0] & k;
+
 	if (ny > nx) {
 		w = x;
 		x = y;
@@ -96,13 +98,16 @@
 		nz = ny;
 		ny = nx;
 		nx = nz;
-	}			/* force x > y */
+	}				/* force x > y */
+
 	if ((nx - ny) >= 0x00730000)
 		return (x + y);	/* x/y >= 2**116 */
+
 	if (nx < 0x5ff30000 && ny > 0x205b0000) {	/* medium x,y */
 		/* save and set RD to Rounding to nearest */
 		rd = __swapRD(fp_nearest);
 		w = x - y;
+
 		if (w > y) {
 			pt1[n0] = px[n0];
 			pt1[n1] = px[n1];
@@ -121,8 +126,10 @@
 			t2 = x - t1;
 			x = sqrtl(t1 * y1 - (w * (-w) - (t2 * y1 + y2 * x)));
 		}
+
 		if (rd != fp_nearest)
 			(void) __swapRD(rd);	/* restore rounding mode */
+
 		return (x);
 	} else {
 		if (nx == k || ny == k) {	/* x or y is INF or NaN */
@@ -132,16 +139,20 @@
 				t2 = y;
 			else
 				t2 = x + y;	/* invalid if x or y is sNaN */
+
 			return (t2);
 		}
+
 		if (ny == 0) {
 			if (y == zero || x == zero)
 				return (x + y);
+
 			t1 = scalbnl(one, 16381);
 			x *= t1;
 			y *= t1;
 			return (scalbnl(one, -16381) * hypotl(x, y));
 		}
+
 		j = nx - 0x3fff0000;
 		px[n0] -= j;
 		py[n0] -= j;
